@@ -49,7 +49,7 @@ unsigned int ReSIDBuilder::create(unsigned int sids)
             sidobjs.insert(new ReSID(this));
         }
         // Memory alloc failed?
-        catch (std::bad_alloc&)
+        catch (std::bad_alloc const &)
         {
             m_errorBuffer.assign(name()).append(" ERROR: Unable to create ReSID object");
             m_status = false;
