@@ -31,22 +31,22 @@ namespace reSIDfp
 
 const int EnvelopeGenerator::adsrtable[16] =
 {
-    0x7F00,
-    0x0006,
-    0x003C,
-    0x0330,
-    0x20C0,
-    0x6755,
-    0x3800,
-    0x500E,
-    0x1212,
-    0x0222,
-    0x1848,
-    0x59B8,
-    0x3840,
-    0x77E2,
-    0x7625,
-    0x0A93
+    0x007f,
+    0x3000,
+    0x1e00,
+    0x0660,
+    0x0182,
+    0x5573,
+    0x000e,
+    0x3805,
+    0x2424,
+    0x2220,
+    0x090c,
+    0x0ecd,
+    0x010e,
+    0x23f7,
+    0x5237,
+    0x64a8
 };
 
 void EnvelopeGenerator::set_exponential_counter()
