@@ -233,8 +233,8 @@ void EnvelopeGenerator::clock()
     {
         // it wasn't a match, clock the LFSR once
         // by performing XOR on last 2 bits
-        const int feedback = ((lfsr >> 14) ^ (lfsr >> 13)) & 0x01;
-        lfsr = ((lfsr << 1) & 0x7fff) | feedback;
+        const int feedback = ((lfsr << 14) ^ (lfsr << 13)) & 0x4000;
+        lfsr = (lfsr >> 1) | feedback;
         return;
     }
 
@@ -286,16 +286,7 @@ void EnvelopeGenerator::clock()
                 return;
             }
 
-            if (exponential_counter_period != 1)
-            {
-                // unlikely (15%)
-                // The decrement is delayed one cycle.
-                envelope_pipeline = true;
-                return;
-            }
-
-            -- envelope_counter;
-            break;
+            // fall-through
 
         case RELEASE:
 
@@ -307,7 +298,6 @@ void EnvelopeGenerator::clock()
             //
             if (exponential_counter_period != 1)
             {
-                // likely (~50%)
                 // The decrement is delayed one cycle.
                 envelope_pipeline = true;
                 return;
