@@ -21,7 +21,9 @@
 
 #include "FilterModelConfig.h"
 
-#include <math.h>
+#include <cmath>
+
+#include "siddefs-fp.h"
 
 #include "Dac.h"
 #include "Integrator.h"
@@ -61,7 +63,6 @@ std::auto_ptr<FilterModelConfig> FilterModelConfig::instance(0);
 
 FilterModelConfig* FilterModelConfig::getInstance()
 {
-
     if (!instance.get())
     {
         instance.reset(new FilterModelConfig());
@@ -227,7 +228,6 @@ FilterModelConfig::FilterModelConfig() :
 
 FilterModelConfig::~FilterModelConfig()
 {
-
     for (int i = 0; i < 7; i++)
     {
         delete [] summer[i];
