@@ -27,7 +27,6 @@ namespace reSIDfp
 
 WaveformCalculator* WaveformCalculator::getInstance()
 {
-
     static WaveformCalculator instance;
     return &instance;
 }
@@ -40,15 +39,15 @@ WaveformCalculator* WaveformCalculator::getInstance()
 const CombinedWaveformConfig WaveformCalculator::config[2][4] =
 {
     { /* kevtris chip G (6581r2/r3) */
-        {0.880815f, 0.f, 0.f, 0.3279614f, 0.5999545f}, // error 1795
-        {0.8924618f, 2.014781f, 1.003332f, 0.02992322f, 0.f}, // error 11610
-        {0.8646501f, 1.712586f, 1.137704f, 0.02845423f, 0.f}, // error 21307
-        {0.9527834f, 1.794777f, 0.f, 0.09806272f, 0.7752482f}, // error 196
+        {0.880592f, 0.f, 0.f, 0.327589f, 0.611491f}, // error 1741
+        {0.892438f, 2.00995f, 1.00392f, 0.0298894f, 0.f}, // error 11418
+        {0.874544f, 1.91885f, 1.12702f, 0.0312843f, 0.f}, // error 21223
+        {0.930481f, 1.42322f, 0.f, 0.0481732f, 0.752611f}, // error 78
     }, { /* kevtris chip V (8580) */
-        {0.9781665f, 0.f, 0.9899469f, 8.087667f, 0.8226412f}, // error 5546
-        {0.9097769f, 2.039997f, 0.9584096f, 0.1765447f, 0.f}, // error 18763
-        {0.9231212f, 2.084788f, 0.9493895f, 0.1712518f, 0.f}, // error 17103
-        {0.9845552f, 1.415612f, 0.9703883f, 3.68829f, 0.8265008f}, // error 3319
+        {0.979807f, 0.f, 0.990736f, 9.23845f, 0.82445f}, // error 5371
+        {0.909646f, 2.03944f, 0.958471f, 0.175597f, 0.f}, // error 18507
+        {0.918338f, 2.00243f, 0.949102f, 0.180793f, 0.f}, // error 16763
+        {0.984532f, 1.53602f, 0.961933f, 3.46871f, 0.803955f}, // error 3199
     },
 };
 
@@ -88,7 +87,7 @@ short WaveformCalculator::calculateCombinedWaveform(CombinedWaveformConfig confi
     /* S with strong top bit for 6581 */
     for (int i = 0; i < 12; i++)
     {
-        o[i] = (accumulator >> 12 & (1 << i)) != 0 ? 1.f : 0.f;
+        o[i] = ((accumulator >> 12) & (1 << i)) != 0 ? 1.f : 0.f;
     }
 
     /* convert to T */
@@ -98,7 +97,7 @@ short WaveformCalculator::calculateCombinedWaveform(CombinedWaveformConfig confi
 
         for (int i = 11; i > 0; i--)
         {
-            o[i] = top ? 1.0f - o[i - 1] :  o[i - 1];
+            o[i] = top ? 1.0f - o[i - 1] : o[i - 1];
         }
 
         o[0] = 0.f;
@@ -163,7 +162,7 @@ short WaveformCalculator::calculateCombinedWaveform(CombinedWaveformConfig confi
 
     for (int i = 0; i < 12; i++)
     {
-        if (o[i] - config.bias > 0.f)
+        if (o[i] > config.bias )
         {
             value |= 1 << i;
         }
