@@ -24,10 +24,12 @@
 
 #include <assert.h>
 #include <string.h>
-#include <math.h>
+#include <cmath>
 #include <iostream>
 #include <sstream>
 
+#include "siddefs-fp.h"
+
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
@@ -163,7 +165,7 @@ SincResampler::SincResampler(double clockFrequency, double samplingFrequency, do
         * The filter test program indicates that the filter performs well, though. */
     }
 
-    std::ostringstream o(std::ostringstream::out);
+    std::ostringstream o;
     o << firN << "," << firRES << "," << cyclesPerSampleD;
     const std::string firKey = o.str();
     std::map<std::string, array<short> >::iterator lb = FIR_CACHE.lower_bound(firKey);
