@@ -31,30 +31,24 @@
 
 #include "sidplayfp/sidendian.h"
 
-typedef struct
+const MOS656X::model_data_t MOS656X::modelData[] =
 {
-    unsigned int cyclesPerLine;
-    unsigned int rasterLines;
-} model_data_t;
-
-const model_data_t modelData[] =
-{
-    {262, 64}, // Old NTSC
-    {263, 65}, // NTSC-M
-    {312, 63}, // PAL-B
-    {312, 65}, // PAL-N
+    {262, 64, &MOS656X::clockOldNTSC},  // Old NTSC
+    {263, 65, &MOS656X::clockNTSC},     // NTSC-M
+    {312, 63, &MOS656X::clockPAL},      // PAL-B
+    {312, 65, &MOS656X::clockNTSC},     // PAL-N
 };
 
 const char *MOS656X::credit =
 {   // Optional information
-    "MOS656X (VICII) Emulation:\n"
+    "MOS6567/6569/6572 (VICII) Emulation:\n"
     "\tCopyright (C) 2001 Simon White\n"
     "\tCopyright (C) 2007-2010 Antti Lankila\n"
     "\tCopyright (C) 2011-2013 Leandro Nini\n"
 };
 
 
-MOS656X::MOS656X (EventContext *context) :
+MOS656X::MOS656X(EventContext *context) :
     Event("VIC Raster"),
     event_context(*context),
     sprite_enable(regs[0x15]),
@@ -64,7 +58,7 @@ MOS656X::MOS656X (EventContext *context) :
     chip (MOS6569);
 }
 
-void MOS656X::reset ()
+void MOS656X::reset()
 {
     irqFlags     = 0;
     irqMask      = 0;
@@ -73,32 +67,33 @@ void MOS656X::reset ()
     rasterY      = maxRasters - 1;
     lineCycle    = 0;
     areBadLinesEnabled = false;
-    m_rasterClk  = 0;
+    rasterClk    = 0;
     vblanking    = lp_triggered = false;
     lpx          = 0;
     lpy          = 0;
     sprite_dma   = 0;
-    sprite_expand_y = 0xff;
     memset(regs, 0, sizeof (regs));
     memset(sprite_mc_base, 0, sizeof (sprite_mc_base));
+    memset(sprite_mc, 0, sizeof (sprite_mc));
     event_context.cancel(*this);
     event_context.schedule(*this, 0, EVENT_CLOCK_PHI1);
 }
 
-void MOS656X::chip (model_t model)
+void MOS656X::chip(model_t model)
 {
     maxRasters    = modelData[model].cyclesPerLine;
     cyclesPerLine = modelData[model].rasterLines;
+    clock         = modelData[model].clock;
 
     reset ();
 }
 
-uint8_t MOS656X::read (uint_least8_t addr)
+uint8_t MOS656X::read(uint_least8_t addr)
 {
     addr &= 0x3f;
 
     // Sync up timers
-    clock ();
+    sync();
 
     switch (addr)
     {
@@ -129,14 +124,14 @@ uint8_t MOS656X::read (uint_least8_t addr)
     }
 }
 
-void MOS656X::write (uint_least8_t addr, uint8_t data)
+void MOS656X::write(uint_least8_t addr, uint8_t data)
 {
     addr &= 0x3f;
 
     regs[addr] = data;
 
     // Sync up timers
-    clock ();
+    sync();
 
     switch (addr)
     {
@@ -152,11 +147,13 @@ void MOS656X::write (uint_least8_t addr, uint8_t data)
         if (rasterY == FIRST_DMA_LINE)
             areBadLinesEnabled |= readDEN();
 
+        const bool oldBadLine = isBadLine;
+
         /* Re-evaluate badline condition */
         isBadLine = evaluateIsBadLine();
 
         // Start bad dma line now
-        if (isBadLine && (lineCycle < 53))
+        if ((isBadLine != oldBadLine) && (lineCycle < 53))
             event_context.schedule(badLineStateChangeEvent, 0, EVENT_CLOCK_PHI1);
         break;
     }
@@ -166,7 +163,20 @@ void MOS656X::write (uint_least8_t addr, uint8_t data)
         break;
 
     case 0x17:
-        sprite_expand_y |= ~data; // 3.8.1-1
+    {
+        uint8_t mask = 1;
+        for (unsigned int i=0; i<8; i++, mask<<=1)
+        {
+            if ((sprite_enable & mask) && !(sprite_y_expansion & mask))
+            {
+                if (lineCycle == 14)
+                {
+                    sprite_mc[i] = (0x2a & (sprite_mc_base[i] & sprite_mc[i])) | (0x15 & (sprite_mc_base[i] | sprite_mc[i]));
+                }
+                sprite_y_expansion |= mask;
+            }
+        }
+    }
         break;
 
     case 0x19:
@@ -201,227 +211,404 @@ void MOS656X::handleIrqState()
     }
 }
 
-void MOS656X::event ()
+void MOS656X::event()
 {
-    const event_clock_t delay = clock();
+    const event_clock_t cycles = event_context.getTime(rasterClk, event_context.phase());
+
+    event_clock_t delay;
+
+    if (cycles)
+    {
+        // Update x raster
+        rasterClk += cycles;
+        lineCycle += cycles;
+        lineCycle %= cyclesPerLine;
+
+        delay = (this->*clock)();
+    }
+    else
+        delay = 1;
+
     event_context.schedule(*this, delay - event_context.phase(), EVENT_CLOCK_PHI1);
 }
 
-event_clock_t MOS656X::clock ()
+event_clock_t MOS656X::clockPAL()
 {
     event_clock_t delay = 1;
 
-    const event_clock_t cycles = event_context.getTime(m_rasterClk, event_context.phase());
-
-    // Cycle already executed check
-    if (!cycles)
-        return delay;
-
-    // Update x raster
-    m_rasterClk += cycles;
-    lineCycle    += cycles;
-    const uint_least16_t cycle = (lineCycle + 9) % cyclesPerLine;
-    lineCycle    %= cyclesPerLine;
-
-    switch (cycle)
+    switch (lineCycle)
     {
     case 0:
-    {   // Calculate sprite DMA
-        const uint8_t y = rasterY & 0xff;
-        sprite_expand_y ^= sprite_y_expansion; // 3.8.1-2
-        uint8_t mask = 1;
-        for (unsigned int i=1; i<0x10; i+=2, mask<<=1)
-        {   // 3.8.1-3
-            if ((sprite_enable & mask) && (y == regs[i]))
-            {
-                sprite_dma |= mask;
-                sprite_mc_base[i >> 1] = 0;
-                sprite_expand_y &= ~(sprite_y_expansion & mask);
-            }
-        }
-
-        if (sprite_dma & 0x01)
-        {
-            setBA (false);
-            delay = 2;
-        }
-        else
-        {
-            setBA (true);
-            // No sprites before next compulsory cycle
-            delay = (sprite_dma & 0x1f) ? 2 : 9;
-        }
+        checkVblank();
+        endDma<2>();
         break;
-    }
 
     case 1:
-        break;
+        vblank();
+        startDma<5>();
 
-    case 2:
-        if (sprite_dma & 0x02)
-            setBA(false);
-        break;
-
-    case 3:
-        if (!(sprite_dma & 0x03))
-            setBA(true);
-        break;
-
-    case 4:
-        if (sprite_dma & 0x04)
-            setBA(false);
-        break;
-
-    case 5:
-        if (!(sprite_dma & 0x06))
-            setBA(true);
-        break;
-
-    case 6:
-        if (sprite_dma & 0x08)
-            setBA(false);
-        break;
-
-    case 7:
-        if (!(sprite_dma & 0x0c))
-            setBA(true);
-        break;
-
-    case 8:
-        if (sprite_dma & 0x10)
-            setBA(false);
-        break;
-
-    case 9:  // IRQ occurred (xraster != 0)
-        if (rasterY == (maxRasters - 1))
-            vblanking = true;
-        else
-        {
-            rasterY++;
-            // Trigger raster IRQ if IRQ line reached
-            if (rasterY == raster_irq)
-                activateIRQFlag(IRQ_RASTER);
-        }
-        if (!(sprite_dma & 0x18))
-            setBA(true);
-        break;
-
-    case 10:  // Vertical blank (line 0)
-        if (vblanking)
-        {
-            vblanking = lp_triggered = false;
-            rasterY = 0;
-            // Trigger raster IRQ if IRQ in line 0
-            if (raster_irq == 0)
-                activateIRQFlag(IRQ_RASTER);
-        }
-        if (sprite_dma & 0x20)
-            setBA(false);
         // No sprites before next compulsory cycle
-        else if (!(sprite_dma & 0xf8))
+        if (!(sprite_dma & 0xf8))
            delay = 10;
         break;
 
+    case 2:
+        endDma<3>();
+        break;
+
+    case 3:
+        startDma<6>();
+        break;
+
+    case 4:
+        endDma<4>();
+        break;
+
+    case 5:
+        startDma<7>();
+        break;
+
+    case 6:
+        endDma<5>();
+
+        delay = (sprite_dma & 0xc0) ? 2 : 5;
+        break;
+
+    case 7:
+        break;
+
+    case 8:
+        endDma<6>();
+
+        delay = (sprite_dma & 0x80) ? 2 : 3;
+        break;
+
+    case 9:
+        break;
+
+    case 10:
+        updateMc();
+        endDma<7>();
+        break;
+
     case 11:
-        if (!(sprite_dma & 0x30))
-            setBA(true);
+        startBadline();
+
+        delay = 4;
         break;
 
     case 12:
-        if (sprite_dma & 0x40)
-            setBA(false);
-        break;
-
     case 13:
-        if (!(sprite_dma & 0x60))
-            setBA(true);
-        break;
-
     case 14:
-        if (sprite_dma & 0x80)
-            setBA(false);
         break;
 
     case 15:
-        if (!(sprite_dma & 0xc0))
-        {
-            setBA(true);
-            delay = 5;
-        } else
-            delay = 2;
-        break;
+        updateMcBase();
 
-    case 16:
-        break;
-
-    case 17:
-        if (!(sprite_dma & 0x80))
-        {
-            setBA(true);
-            delay = 3;
-        } else
-            delay = 2;
-        break;
-
-    case 18:
-        break;
-
-    case 19:
-        setBA(true);
-        break;
-
-    case 20: // Start bad line
-    {   // In line $30, the DEN bit controls if Bad Lines can occur
-        if (rasterY == FIRST_DMA_LINE)
-            areBadLinesEnabled = readDEN();
-
-        // Test for bad line condition
-        isBadLine = evaluateIsBadLine();
-
-        if (isBadLine)
-        {   // DMA starts on cycle 23
-            setBA(false);
-        }
-        delay = 3;
-        break;
-    }
-
-    case 23:
-    {   // 3.8.1-7
-        for (unsigned int i=0; i<8; i++)
-        {
-            if (sprite_expand_y & (1 << i))
-                sprite_mc_base[i] += 2;
-        }
-        break;
-    }
-
-    case 24:
-    {
-        uint8_t mask = 1;
-        for (unsigned int i=0; i<8; i++, mask<<=1)
-        {   // 3.8.1-8
-            if (sprite_expand_y & mask)
-                sprite_mc_base[i]++;
-            if ((sprite_mc_base[i] & 0x3f) == 0x3f)
-                sprite_dma &= ~mask;
-        }
         delay = 39;
         break;
-    }
 
-    case 63: // End DMA - Only get here for non PAL
-        setBA(true);
-        delay = cyclesPerLine - cycle;
+    case 54:
+        checkSpriteDma();
+        startDma<0>();
+        break;
+
+    case 55:
+        checkSpriteDmaExp();
+        startDma<0>();
+
+        // No sprites before next compulsory cycle
+        if (!(sprite_dma & 0x1f))
+            delay = 8;
+        break;
+
+    case 56:
+        startDma<1>();
+        break;
+
+    case 57:
+        checkSpriteDisplay();
+        break;
+
+    case 58:
+        startDma<2>();
+        break;
+
+    case 59:
+        endDma<0>();
+        break;
+
+    case 60:
+        startDma<3>();
+        break;
+
+    case 61:
+        endDma<1>();
+        break;
+
+    case 62:
+        startDma<4>();
         break;
 
     default:
-        if (cycle < 23)
-            delay = 23 - cycle;
-        else if (cycle < 63)
-            delay = 63 - cycle;
-        else
-            delay = cyclesPerLine - cycle;
+        delay = 54 - lineCycle;
+    }
+
+    return delay;
+}
+
+event_clock_t MOS656X::clockNTSC()
+{
+    event_clock_t delay = 1;
+
+    switch (lineCycle)
+    {
+    case 0:
+        checkVblank();
+        startDma<5>();
+        break;
+
+    case 1:
+        vblank();
+        endDma<3>();
+
+        // No sprites before next compulsory cycle
+        if (!(sprite_dma & 0xf8))
+            delay = 10;
+        break;
+
+    case 2:
+        startDma<6>();
+        break;
+
+    case 3:
+        endDma<4>();
+        break;
+
+    case 4:
+        startDma<7>();
+        break;
+
+    case 5:
+        endDma<5>();
+
+        delay = (sprite_dma & 0xc0) ? 2 : 5;
+        break;
+
+    case 6:
+        break;
+
+    case 7:
+        endDma<6>();
+
+        delay = (sprite_dma & 0x80) ? 2 : 3;
+        break;
+
+    case 8:
+        break;
+
+    case 9:
+        updateMc();
+        endDma<7>();
+
+        delay = 2;
+        break;
+
+    case 10:
+        break;
+
+    case 11:
+        startBadline();
+
+        delay = 4;
+        break;
+
+    case 12:
+    case 13:
+    case 14:
+        break;
+
+    case 15:
+        updateMcBase();
+
+        delay = 40;
+        break;
+
+    case 55:
+        checkSpriteDmaExp();
+        startDma<0>();
+        break;
+
+    case 56:
+        checkSpriteDma();
+        startDma<0>();
+
+        // No sprites before next compulsory cycle
+        if (!(sprite_dma & 0x1f))
+            delay = 8;
+        break;
+
+    case 57:
+        startDma<1>();
+        break;
+
+    case 58:
+        checkSpriteDisplay();
+        break;
+
+    case 59:
+        startDma<2>();
+        break;
+
+    case 60:
+        endDma<0>();
+        break;
+
+    case 61:
+        startDma<3>();
+        break;
+
+    case 62:
+        endDma<1>();
+        break;
+
+    case 63:
+        startDma<4>();
+        break;
+
+    case 64:
+        endDma<2>();
+        break;
+
+    default:
+        delay = 55 - lineCycle;
+    }
+
+    return delay;
+}
+
+event_clock_t MOS656X::clockOldNTSC()
+{
+    event_clock_t delay = 1;
+
+    switch (lineCycle)
+    {
+    case 0:
+        checkVblank();
+        endDma<2>();
+        break;
+
+    case 1:
+        vblank();
+        startDma<5>();
+
+        // No sprites before next compulsory cycle
+        if (!(sprite_dma & 0xf8))
+           delay = 10;
+        break;
+
+    case 2:
+        endDma<3>();
+        break;
+
+    case 3:
+        startDma<6>();
+        break;
+
+    case 4:
+        endDma<4>();
+        break;
+
+    case 5:
+        startDma<7>();
+        break;
+
+    case 6:
+        endDma<5>();
+
+        delay = (sprite_dma & 0xc0) ? 2 : 5;
+        break;
+
+    case 7:
+        break;
+
+    case 8:
+        endDma<6>();
+
+        delay = (sprite_dma & 0x80) ? 2 : 3;
+        break;
+
+    case 9:
+        break;
+
+    case 10:
+        updateMc();
+        endDma<7>();
+        break;
+
+    case 11:
+        startBadline();
+
+        delay = 4;
+        break;
+
+    case 12:
+    case 13:
+    case 14:
+        break;
+
+    case 15:
+        updateMcBase();
+
+        delay = 40;
+        break;
+
+    case 55:
+        checkSpriteDmaExp();
+        startDma<0>();
+        break;
+
+    case 56:
+        checkSpriteDma();
+        startDma<0>();
+
+        // No sprites before next compulsory cycle
+        if (!(sprite_dma & 0x1f))
+            delay = 8;
+        break;
+
+    case 57:
+        checkSpriteDisplay();
+        startDma<1>();
+
+        delay = 2;
+        break;
+
+    case 58:
+        break;
+
+    case 59:
+        startDma<2>();
+        break;
+
+    case 60:
+        endDma<0>();
+        break;
+
+    case 61:
+        startDma<3>();
+        break;
+
+    case 62:
+        endDma<1>();
+        break;
+
+    case 63:
+        startDma<4>();
+        break;
+
+    default:
+        delay = 55 - lineCycle;
     }
 
     return delay;
@@ -430,7 +617,7 @@ event_clock_t MOS656X::clock ()
 // Handle light pen trigger
 void MOS656X::lightpen ()
 {   // Synchronise simulation
-    clock ();
+    sync();
 
     if (!lp_triggered)
     {   // Latch current coordinates
