@@ -26,6 +26,8 @@
 
 #include <stdlib.h>
 
+#include <vector>
+
 #include "event.h"
 #include "sidbuilder.h"
 
@@ -34,12 +36,6 @@
 */
 class Mixer : private Event
 {
-private:
-    /**
-    * Scheduling time for next sample mixing event. 5000 is roughly 5 ms
-    */
-    static const int MIXER_EVENT_RATE = 5000;
-
 public:
     /** Maximum allowed volume, must be a power of 2 */
     static const int_least32_t VOLUME_MAX = 1024;
@@ -50,8 +46,7 @@ private:
     */
     EventContext &event_context;
 
-    sidemu *m_chip1;
-    sidemu *m_chip2;
+    std::vector<sidemu *> m_chips;
 
     int oldRandomValue;
     int m_fastForwardFactor;
@@ -91,7 +86,7 @@ public:
     */
     void event();
 
-    void reset() { event_context.schedule(*this, MIXER_EVENT_RATE, EVENT_CLOCK_PHI1); }
+    void reset();
 
     void begin(short *buffer, uint_least32_t count);
 
