@@ -31,14 +31,18 @@
 
 #ifdef HAVE_STRCASECMP
 #   define MYSTRICMP strcasecmp
-#else
+#elif HAVE_STRICMP
 #   define MYSTRICMP stricmp
+#else
+#  error Neither strcasecmp nor stricmp is available.
 #endif
 
 #ifdef HAVE_STRNCASECMP
 #   define MYSTRNICMP strncasecmp
-#else
+#elif HAVE_STRNICMP
 #   define MYSTRNICMP strnicmp
+#else
+#  error Neither strncasecmp nor strnicmp is available.
 #endif
 
 class SidTuneTools
